package com.dahantc.sms.sdk;

import com.alibaba.fastjson.JSON;
import com.dahantc.sms.utils.DateUtil;
import com.dahantc.sms.utils.HttpUtils;
import com.dahantc.sms.utils.Md5Util;
import com.dahantc.sms.utils.StringUtil;

import java.util.HashMap;
import java.util.Map;

/**
 * 短信发送SDK
 * @author wuhandahantc
 * @date 2019/1/2 9:57
 **/
public class SmsSdk {

	/**
	 * 短信发送请求路径
	 */
	private String apiUrl;
	/**
	 * 状态报告 请求路径 https://report.dahancloud.com/
	 */
	private String reportUrl;

	/**
	 * 账号
	 */
	private String account;
	/**
	 * token信息
	 */
	private String token;
	/**
	 * APPID
	 */
	private String appId;

	/**
	 * 设置 请求路径
	 * @param apiUrl 请求路径
	 */
	public void setApiUrl(String apiUrl) {
		this.apiUrl = apiUrl;
	}

	/**
	 * 账户id
	 * @param accountSid 账户信息
	 */
	public void setAccountSid(String accountSid) {
		this.account = accountSid;
	}

	/**
	 * 账户token
	 * @param accountToken token
	 */
	public void setAuthToken(String accountToken) {
		this.token = accountToken;
	}

	/**
	 * 设置应用id
	 * @param appId 应用id
	 */
	public void setAppId(String appId) {
		this.appId = appId;
	}

	public void setReportUrl(String reportUrl) {
		this.reportUrl = reportUrl;
	}

	/**
	 * 发送短信（实际调用请保证这些参数真实有效！）
	 * @param to 短信接收号码
	 * @param templateId 短信模板id
	 * @param datas 参数
	 * @date 2019/1/2 10:04
	 * @return java.util.Map<java.lang.String,java.lang.Object>
	 **/
	public SmsResult sendSms(String to, String templateId, String[] datas) {
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("appId", appId);
		param.put("to", to);
		param.put("templateId", templateId);
		param.put("datas", datas);
		SmsResult smsResult = paramsEmpty(apiUrl,account,token,appId,to,templateId);
		if (smsResult != null){
			return smsResult;
		}
		String currentTime = DateUtil.currentTime();
		String sendUrl =apiUrl+"API/sendMessage?sig="+Md5Util.md5(account + token + currentTime);
		System.out.println(sendUrl);
		String result = HttpUtils.sendMessage(param, sendUrl, account, currentTime);
		if(StringUtil.isEmpty(result)){
			return SmsResult.err("000010","【服务器】服务器请求出错，请确认参数是否正确，如无法解决，请联系工作人员");
		}
		return JSON.parseObject(result,SmsResult.class);
	}
	
	/**
	 *----------------------------------------------------------------------
	 * 获取短信状态报告
	 * @date 2019-01-16 17:15
	 * @return java.lang.String
	 *----------------------------------------------------------------------
	 **/
	public ReportResult smsReport(){
		String currentTime = DateUtil.currentTime();
		String reqUrl = this.reportUrl +"sms/report?sig="+Md5Util.md5(account + token + currentTime);
		System.out.println(reqUrl);
		String resp = HttpUtils.report(reqUrl, account,token);
		if (!StringUtil.isEmpty(resp)){
			try {
				System.out.println("状态报告返回内容：" + resp);
				return JSON.parseObject(resp,ReportResult.class);
			}catch (Exception e){
				e.printStackTrace();
			}
		}
		return null;
	}



	/**
	 * 短信提交参数校验
	 * @param apiUrl 请求路径
	 * @param account 账号
	 * @param token token
	 * @param appId 应用id
	 * @param to 接收号码字符串
	 * @param templateId 模板id
	 * @date 2019/1/2 10:14
	 * @return com.dahantc.sms.sdk.SmsResult
	 **/
	private SmsResult paramsEmpty(String apiUrl,String account,String token,String appId,String to,String templateId){
		if (StringUtil.isEmpty(apiUrl)) {
			return SmsResult.err("000019","【短信】url空");
		}
		if (StringUtil.isEmpty(account)) {
			return SmsResult.err("000017","【账号】帐号空");
		}
		if (StringUtil.isEmpty(token)) {
			return SmsResult.err("000018","【账号】帐号令牌空");
		}
		if (StringUtil.isEmpty(appId)) {
			return SmsResult.err("000016","【应用】应用ID为空");
		}
		if (StringUtil.isEmpty(to)) {
			return SmsResult.err("000006","【短信】接收短信的手机号码为空");
		}
		if (StringUtil.isEmpty(templateId)) {
			return SmsResult.err("000008","【短信】短信模板为空或未设置");
		}
		return null;
	}
}