package com.dahantc.sms.utils;

import com.alibaba.fastjson.JSON;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.Map;

/**
 * 日期工具类
 * @author wuhandahantc
 * @date 2019/1/2 9:57
 **/
public class HttpUtils {
	
	private static final String ENCODING_UTF_8 = "UTF-8";
	
	/**
	 * 发送消息
	 * @param params 参数
	 * @param pathUrl 请求路径
	 * @param account 账号信息
	 * @param currentDate 当前时间
	 * @date 2019/1/2 10:40
	 * @return java.lang.String
	 **/
	public static String sendMessage(Map<String, Object> params, String pathUrl, String account, String currentDate) {
		String authorization = Md5Util.base64Encode(account+":"+currentDate);
		System.out.println(authorization);
		try {
			URL url = new URL(pathUrl);
			HttpURLConnection urlConnection = (HttpURLConnection) url.openConnection();
			urlConnection.setConnectTimeout(3000);
			urlConnection.setRequestMethod("POST");
			// 表示从服务器获取数据
			urlConnection.setDoInput(true);
			// 表示向服务器写数据
			urlConnection.setDoOutput(true);
			String requestString = JSON.toJSONString(params);
			byte[] mydata = requestString.getBytes("utf-8");
			// 表示设置请求体的类型是文本类型
			urlConnection.setRequestProperty("Content-Type","application/json;charset=utf-8");
			urlConnection.setRequestProperty("Content-Length", String.valueOf(mydata.length));
			urlConnection.setRequestProperty("Authorization", authorization);
			// 获得输出流,向服务器输出数据
			OutputStream outputStream = urlConnection.getOutputStream();
			outputStream.write(mydata, 0, mydata.length);
			outputStream.close();
			// 获得服务器响应的结果和状态码
			int responseCode = urlConnection.getResponseCode();
			if (responseCode == 200) {
				return changeInputStream(urlConnection.getInputStream());
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
		return null;
	}


	/**
	 * 发送消息
	 * @param pathUrl 请求路径
	 * @param account 账号信息
	 * @param token 授权令牌
	 * @date 2019/1/2 10:40
	 * @return java.lang.String
	 **/
	public static String report(String pathUrl,String account, String token) {
		try {
			URL url = new URL(pathUrl);
			HttpURLConnection urlConnection = (HttpURLConnection) url.openConnection();
			urlConnection.setConnectTimeout(3000);
			urlConnection.setRequestMethod("POST");
			// 表示从服务器获取数据
			urlConnection.setDoInput(true);
			// 表示向服务器写数据
			urlConnection.setDoOutput(true);
			// 表示设置请求体的类型是文本类型
			urlConnection.setRequestProperty("Content-Type","application/json;charset=utf-8");
			String currentDate = DateUtil.currentTime();
			String authorization = Md5Util.base64Encode(account+":"+currentDate);
			String sig = Md5Util.md5(account + token + currentDate);
			urlConnection.setRequestProperty("Authorization", authorization);
			urlConnection.setRequestProperty("sig", sig);
			// 获得服务器响应的结果和状态码
			int responseCode = urlConnection.getResponseCode();
			if (responseCode == 200) {
				return changeInputStream(urlConnection.getInputStream());
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
		return null;
	}

	/**
	 * 将输入流转化为字符串
	 * @param inputStream 输入流
	 * @return String
	 */
	private static String changeInputStream(InputStream inputStream) {
		String result = null;
		if (inputStream != null) {
			try {
				ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
				byte[] data = new byte[1024];
				int len = 0;
				while ((len = inputStream.read(data)) != -1) {
					outputStream.write(data, 0, len);
				}
				result = new String(outputStream.toByteArray(), ENCODING_UTF_8);
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
		return result;
	}
}
